@@ -9,25 +9,52 @@ import logging
 import tempfile
 
 
+def create_saspyconn(sasobjsp_host, sasobjsp_port, java='/usr/bin/java'):
+    saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
+    saspy_conn.write(f"""SAS_config_names=['sasconnection']
+SAS_config_options = {{'lock_down': False,
+                    'verbose'  : True,
+                    'prompt'   : True
+                    }}
+SAS_output_options = {{'output' : 'html5'}} 
+sasconnection = {{'java'      : '{java}',
+            'iomhost'   : ['{sasobjsp_host}'],
+            'iomport'   : {sasobjsp_port},
+            'encoding': 'cyrillic',
+            'options' : ["-fullstimer"]
+            }}""")
+    saspy_conn.seek(0)
+    return saspy_conn
+
+
 class Abstract_SAS(saspy.SASsession):
     def __init__(self, sasobjsp_user,
                        sasobjsp_pass,
                        sasobjsp_host,
-                       sasobjsp_port,  **kwargs):
+                       sasobjsp_port,
+                       java='/usr/bin/java',
+                       **kwargs):
         self.sasobjsp_host = sasobjsp_host
         self.sasobjsp_port = sasobjsp_port
         self.sasobjsp_user = sasobjsp_user
         self.sasobjsp_pass = sasobjsp_pass
-        self.connected = False
+        self.java = java
+        self.saspy_conn = create_saspyconn(sasobjsp_host=self.sasobjsp_host,
+                                           sasobjsp_port=self.sasobjsp_port,
+                                           java=self.java)
 
-    def connect(self):
-        connection = get_sas_connect(sasobjsp_host=self.sasobjsp_host,
-                                     sasobjsp_port=self.sasobjsp_port,
-                                     sasobjsp_user=self.sasobjsp_user,
-                                     sasobjsp_pass=self.sasobjsp_pass)
-        if connection:
-            self.connected = True
-            return self
+        self.connected = False
+        super(Abstract_SAS, self).__init__(cfgfile=self.saspy_conn.name, omruser=self.sasobjsp_user,
+                                           omrpw=self.sasobjsp_pass)
+
+    # def connect(self):
+    #     connection = get_sas_connect(sasobjsp_host=self.sasobjsp_host,
+    #                                  sasobjsp_port=self.sasobjsp_port,
+    #                                  sasobjsp_user=self.sasobjsp_user,
+    #                                  sasobjsp_pass=self.sasobjsp_pass)
+    #     if connection:
+    #         self.connected = True
+    #         return self
 
     def disconnect(self):
         if self.connected:
